jQuery(function ($) {
    var $fields = $("#bookme-pro-custom-fields"),
        $cf_per_service = $('#bookme_pro_custom_fields_per_service'),
        $cf_merge_repetitive = $('#bookme_pro_custom_fields_merge_repetitive');

    $('.tse-scrollable').TrackpadScrollEmulator();



    $fields.sortable({
        axis: 'y',
        handle: '.bookme-pro-js-handle'
    });

    $cf_merge_repetitive.data('default', $cf_merge_repetitive.val());

    $cf_per_service
        .data('default', $cf_per_service.val())
        .change(function () {
            $('.bookme-pro-services-holder').toggle($(this).val() == 1);
        });

    /**
     * Build initial fields.
     */
    restoreFields();

    /**
     * On "Add new field" button click.
     */
    $('#bookme-pro-js-add-fields').on('click', 'button', function () {
        addField($(this).data('type'));
    });

    /**
     * On "Add new item" button click.
     */
    $fields.on('click', '.bookme-pro-cf-item', function () {
        addItem($(this).prev('ul'), $(this).data('type'));
    });

    /**
     * Delete field or checkbox/radio button/drop-down option.
     */
    $fields.on('click', '.bookme-pro-js-delete', function (e) {
        e.preventDefault();
        $(this).closest('li').fadeOut('fast', function () {
            $(this).remove();
        });
    });

    /**
     * Submit custom fields form.
     */
    $('#ajax-send-custom-fields').on('click', function (e) {
        e.preventDefault();
        var ladda = Ladda.create(this),
            data = [];
        ladda.start();
        $fields.children('li').each(function () {
            var $this = $(this),
                field = {};
            switch ($this.data('type')) {
                case 'checkboxes':
                case 'radio-buttons':
                case 'drop-down':
                    field.items = [];
                    $this.find('ul.bookme-pro-items li').each(function () {
                        field.items.push($(this).find('input').val());
                    });
                case 'textarea':
                case 'text-field':
                case 'text-content':
                case 'captcha':
                    field.type = $this.data('type');
                    field.label = $this.find('.bookme-pro-label').val();
                    field.required = $this.find('.bookme-pro-required').prop('checked');
                    field.id = $this.data('bookme-pro-field-id');
                    field.services = $this.find('.bookme-pro-services-holder .bookme-pro-js-service-selector').val()
            }
            data.push(field);
        });
        $.ajax({
            type: 'POST',
            url: ajaxurl,
            xhrFields: {withCredentials: true},
            data: {
                action: 'bookme_pro_save_custom_fields',
                csrf_token: BookmeProL10n.csrf_token,
                fields: JSON.stringify(data),
                bookme_pro_custom_fields_per_service: $cf_per_service.val(),
                bookme_pro_custom_fields_merge_repetitive: $cf_merge_repetitive.val()
            },
            complete: function () {
                ladda.stop();
                bookmeProAlert({success: [BookmeProL10n.saved]});
            }
        });
    });

    /**
     * On 'Reset' click.
     */
    $('button[type=reset]').on('click', function () {
        $fields.empty();
        restoreFields();
    });

    /**
     * Add new field.
     *
     * @param type
     * @param id
     * @param label
     * @param required
     * @param services
     * @returns {*|jQuery}
     */
    function addField(type, id, label, required, services) {
        var $new_field = $('ul#bookme-pro-templates > li[data-type=' + type + ']').clone();
        // Set id, label and required.
        if (typeof id == 'undefined') {
            id = Math.floor((Math.random() * 100000) + 1);
        }
        if (typeof label == 'undefined') {
            label = '';
        }
        if (typeof required == 'undefined') {
            required = false;
        }
        $new_field
            .hide()
            .data('bookme-pro-field-id', id)
            .find('.bookme-pro-required').prop({
            id: 'required-' + id,
            checked: required
        })
            .next('label').attr('for', 'required-' + id)
            .end().end()
            .find('.bookme-pro-label').val(label)
            .end()
            .find('.bookme-pro-services-holder .bookme-pro-js-service-selector').val(services);

        var $service_selector = $new_field.find('.bookme-pro-services-holder .bookme-pro-js-service-selector');
        $service_selector.multiselect({
            texts: {
                placeholder: $service_selector.data('placeholder'), // text to use in dummy input
                selectedOptions: ' ' + $service_selector.data('selected'),      // selected suffix text
                selectAll: $service_selector.data('selectall'),     // select all text
                unselectAll: $service_selector.data('unselectall'),   // unselect all text
                noneSelected: $service_selector.data('nothing'),   // None selected text
                allSelected: $service_selector.data('allselected')
            },
            showCheckbox: false,  // display the checkbox to the user
            selectAll: true, // add select all option
            minHeight: 20,
            maxPlaceholderOpts : 1
        });

        // Add new field to the list.
        $fields.append($new_field);
        $new_field.fadeIn('fast');
        // Make it sortable.
        $new_field.find('ul.bookme-pro-items').sortable({
            axis: 'y',
            handle: '.bookme-pro-js-handle'
        });
        // Set focus to label field.
        $new_field.find('.bookme-pro-label').focus();

        return $new_field;
    }

    /**
     * Add new checkbox/radio button/drop-down option.
     *
     * @param $ul
     * @param type
     * @param value
     * @return {*|jQuery}
     */
    function addItem($ul, type, value) {
        var $new_item = $('ul#bookme-pro-templates > li[data-type=' + type + ']').clone();
        if (typeof value != 'undefined') {
            $new_item.find('input').val(value);
        }
        $new_item.hide().appendTo($ul).fadeIn('fast').find('input').focus();

        return $new_item;
    }

    /**
     * Restore fields from BookmeProL10n.custom_fields.
     */
    function restoreFields() {
        if (BookmeProL10n.custom_fields) {
            var custom_fields = jQuery.parseJSON(BookmeProL10n.custom_fields);
            $.each(custom_fields, function (i, field) {
                var $new_field = addField(field.type, field.id, field.label, field.required, field.services);
                // add children
                if (field.items) {
                    $.each(field.items, function (i, value) {
                        addItem($new_field.find('ul.bookme-pro-items'), field.type + '-item', value);
                    });
                }
            });
        }

        $cf_merge_repetitive.val($cf_merge_repetitive.data('default'));
        $cf_per_service.val($cf_per_service.data('default'));
        $cf_per_service.change();

        $(':focus').blur();
    }

    $('.bookme-pro-popover').popover({trigger: 'hover'});

    $('[data-toggle="popover"]').popover({
        html: true,
        placement: 'top',
        trigger: 'hover',
        template: '<div class="popover bookme-pro-font-xs" style="width: 220px" role="tooltip"><div class="popover-arrow"></div><h3 class="popover-title"></h3><div class="popover-content"></div></div>'
    });
});