<?php if (!defined('ABSPATH')) exit; // Exit if accessed directly
use BookmePro\Lib\Utils\Common;
use BookmePro\Lib\Utils\Price;
use BookmePro\Lib\Proxy;

?>
<form method="post" action="<?php echo esc_url(add_query_arg('tab', 'payments')) ?>">
    <div class="row">
        <div class="col-lg-4">
            <div class="form-group">
                <label for="bookme_pro_pmt_currency"><?php esc_html_e('Currency', 'bookme_pro') ?></label>
                <select id="bookme_pro_pmt_currency" class="form-control" name="bookme_pro_pmt_currency">
                    <?php foreach (Price::getCurrencies() as $code => $currency) : ?>
                        <option value="<?php echo esc_attr($code) ?>"
                                data-symbol="<?php esc_attr_e($currency['symbol']) ?>" <?php selected(get_option('bookme_pro_pmt_currency'), $code) ?> ><?php echo esc_html($code) ?>
                            (<?php esc_html_e($currency['symbol']) ?>)
                        </option>
                    <?php endforeach ?>
                </select>
            </div>
        </div>
        <div class="col-lg-4">
            <div class="form-group">
                <label for="bookme_pro_pmt_price_format"><?php esc_html_e('Price format', 'bookme_pro') ?></label>
                <select id="bookme_pro_pmt_price_format" class="form-control" name="bookme_pro_pmt_price_format">
                    <?php foreach (Price::getFormats() as $format) : ?>
                        <option value="<?php echo esc_attr($format) ?>" <?php selected(get_option('bookme_pro_pmt_price_format'), $format) ?> ></option>
                    <?php endforeach ?>
                </select>
            </div>
        </div>
        <div class="col-lg-4">
            <?php Common::optionToggle('bookme_pro_pmt_coupons', esc_html__('Coupons', 'bookme_pro')) ?>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_local"><?php esc_html_e('Service paid locally', 'bookme_pro') ?></label>
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_local', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('1', esc_html__('Enabled', 'bookme_pro')))) ?>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_2checkout">2Checkout</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/2Checkout.png', \BookmePro\Lib\Plugin::getMainFile())) ?>"/>
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_2checkout', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('standard_checkout', esc_html__('2Checkout Standard Checkout', 'bookme_pro')))) ?>
            <div class="bookme-pro-2checkout">
                <div class="form-group">
                    <h4><?php esc_html_e('Instructions', 'bookme_pro') ?></h4>
                    <p>
                        <?php _e('In <b>Checkout Options</b> of your 2Checkout account do the following steps:', 'bookme_pro') ?>
                    </p>
                    <ol>
                        <li><?php _e('In <b>Direct Return</b> select <b>Header Redirect (Your URL)</b>.', 'bookme_pro') ?></li>
                        <li><?php _e('In <b>Approved URL</b> enter the URL of your booking page.', 'bookme_pro') ?></li>
                    </ol>
                    <p>
                        <?php esc_html_e('Finally provide the necessary information in the form below.', 'bookme_pro') ?>
                    </p>
                </div>
                <?php Common::optionText('bookme_pro_pmt_2checkout_api_seller_id', esc_html__('Account Number', 'bookme_pro')) ?>
                <?php Common::optionText('bookme_pro_pmt_2checkout_api_secret_word', esc_html__('Secret Word', 'bookme_pro')) ?>
                <?php Common::optionToggle('bookme_pro_pmt_2checkout_sandbox', esc_html__('Sandbox Mode', 'bookme_pro'), null, array(array(0, esc_html__('No', 'bookme_pro')), array(1, esc_html__('Yes', 'bookme_pro')))) ?>
            </div>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_paypal">PayPal</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/paypal.png', \BookmePro\Lib\Plugin::getMainFile())) ?>"/>
        </div>
        <div class="panel-body">
            <div class="form-group">
                <?php Common::optionToggle('bookme_pro_pmt_paypal', null, null,
                    Proxy\PaypalPaymentsStandard::prepareToggleOptions(array(
                        array('disabled', esc_html__('Disabled', 'bookme_pro')),
                        array(BookmePro\Lib\Payment\PayPal::TYPE_EXPRESS_CHECKOUT, 'PayPal Express Checkout'),
                    ))
                ) ?>
            </div>
            <div class="bookme-pro-paypal">
                <div class="bookme-pro-paypal-ec">
                    <?php Common::optionText('bookme_pro_pmt_paypal_api_username', esc_html__('API Username', 'bookme_pro')) ?>
                    <?php Common::optionText('bookme_pro_pmt_paypal_api_password', esc_html__('API Password', 'bookme_pro')) ?>
                    <?php Common::optionText('bookme_pro_pmt_paypal_api_signature', esc_html__('API Signature', 'bookme_pro')) ?>
                </div>
                <?php Proxy\PaypalPaymentsStandard::renderSetUpOptions() ?>
                <?php Common::optionToggle('bookme_pro_pmt_paypal_sandbox', esc_html__('Sandbox Mode', 'bookme_pro'), null, array(array(1, esc_html__('Yes', 'bookme_pro')), array(0, esc_html__('No', 'bookme_pro')))) ?>
            </div>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_authorize_net">Authorize.Net</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/authorize_net.png', \BookmePro\Lib\Plugin::getMainFile())) ?>"/>
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_authorize_net', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('aim', 'Authorize.Net AIM'))) ?>
            <div class="authorize-net">
                <?php Common::optionText('bookme_pro_pmt_authorize_net_api_login_id', esc_html__('API Login ID', 'bookme_pro')) ?>
                <?php Common::optionText('bookme_pro_pmt_authorize_net_transaction_key', esc_html__('API Transaction Key', 'bookme_pro')) ?>
                <?php Common::optionToggle('bookme_pro_pmt_authorize_net_sandbox', esc_html__('Sandbox Mode', 'bookme_pro'), null, array(array(1, esc_html__('Yes', 'bookme_pro')), array(0, esc_html__('No', 'bookme_pro')))) ?>
            </div>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_stripe">Stripe</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/stripe.png', \BookmePro\Lib\Plugin::getMainFile())) ?>">
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_stripe', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('1', esc_html__('Enabled', 'bookme_pro')))) ?>
            <div class="bookme-pro-stripe">
                <div class="form-group">
                    <h4><?php esc_html_e('Instructions', 'bookme_pro') ?></h4>
                    <p>
                        <?php _e('If <b>Publishable Key</b> is provided then BookmePro will use <a href="https://stripe.com/docs/stripe.js" target="_blank">Stripe.js</a><br/>for collecting credit card details.', 'bookme_pro') ?>
                    </p>
                </div>
                <?php Common::optionText('bookme_pro_pmt_stripe_secret_key', esc_html__('Secret Key', 'bookme_pro')) ?>
                <?php Common::optionText('bookme_pro_pmt_stripe_publishable_key', esc_html__('Publishable Key', 'bookme_pro')) ?>
            </div>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_payson">Payson</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/payson.png', \BookmePro\Lib\Plugin::getMainFile())) ?>"/>
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_payson', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('1', esc_html__('Enabled', 'bookme_pro')))) ?>
            <div class="bookme-pro-payson">
                <?php Common::optionText('bookme_pro_pmt_payson_api_agent_id', esc_html__('Agent ID', 'bookme_pro')) ?>
                <?php Common::optionText('bookme_pro_pmt_payson_api_key', esc_html__('API Key', 'bookme_pro')) ?>
                <?php Common::optionText('bookme_pro_pmt_payson_api_receiver_email', esc_html__('Receiver Email (login)', 'bookme_pro')) ?>
                <?php Common::optionFlags('bookme_pro_pmt_payson_funding', array(array('CREDITCARD', esc_html__('Card', 'bookme_pro')), array('INVOICE', esc_html__('Invoice', 'bookme_pro'))), esc_html__('Funding', 'bookme_pro')) ?>
                <?php Common::optionToggle('bookme_pro_pmt_payson_fees_payer', esc_html__('Fees Payer', 'bookme_pro'), null, array(array('PRIMARYRECEIVER', esc_html__('I am', 'bookme_pro')), array('SENDER', esc_html__('Client', 'bookme_pro')))) ?>
                <?php Common::optionToggle('bookme_pro_pmt_payson_sandbox', esc_html__('Sandbox Mode', 'bookme_pro'), null, array(array(0, esc_html__('No', 'bookme_pro')), array(1, esc_html__('Yes', 'bookme_pro')))) ?>
            </div>
        </div>
    </div>

    <div class="panel panel-default">
        <div class="panel-heading">
            <label for="bookme_pro_pmt_mollie">Mollie</label>
            <img class="pull-right"
                 src="<?php echo esc_url(plugins_url('frontend/assets/images/mollie.png', \BookmePro\Lib\Plugin::getMainFile())) ?>"/>
        </div>
        <div class="panel-body">
            <?php Common::optionToggle('bookme_pro_pmt_mollie', null, null, array(array('disabled', esc_html__('Disabled', 'bookme_pro')), array('1', esc_html__('Enabled', 'bookme_pro')))) ?>
            <div class="bookme-pro-mollie">
                <?php Common::optionText('bookme_pro_pmt_mollie_api_key', esc_html__('API Key', 'bookme_pro')) ?>
            </div>
        </div>
    </div>

    <?php BookmePro\Lib\Proxy\Shared::renderPaymentSettings() ?>

    <div class="panel-footer">
        <?php Common::csrf() ?>
        <?php Common::submitButton() ?>
        <?php Common::resetButton('bookme-pro-payments-reset') ?>
    </div>
</form>