<?php if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
    /** @var \BookmePro\Lib\Entities\Staff $staff */
?>
<form>
    <div class="form-group">
        <label for="bookme-pro-full-name"><?php esc_html_e( 'Full name', 'bookme_pro' ) ?></label>
        <input type="text" class="form-control" id="bookme-pro-full-name" name="full_name" value="<?php echo esc_attr( $staff->getFullName() ) ?>"/>
    </div>
    <?php if ( \BookmePro\Lib\Utils\Common::isCurrentUserAdmin() ) : ?>
        <div class="form-group">
            <label for="bookme-pro-wp-user"><?php esc_html_e( 'User', 'bookme_pro' ) ?></label>

            <p class="help-block">
                <?php esc_html_e( 'If this staff member requires separate login to access personal calendar, a regular WP user needs to be created for this purpose.', 'bookme_pro' ) ?>
                <?php esc_html_e( 'User with "Administrator" role will have access to calendars and settings of all staff members, user with another role will have access only to personal calendar and settings.', 'bookme_pro' ) ?>
                <?php esc_html_e( 'If you leave this field blank, this staff member will not be able to access personal calendar using WP backend.', 'bookme_pro' ) ?>
            </p>

            <select class="form-control" name="wp_user_id" id="bookme-pro-wp-user">
                <option value=""><?php esc_html_e( 'Select from WP users', 'bookme_pro' ) ?></option>
                <?php foreach ( $users_for_staff as $user ) : ?>
                    <option value="<?php echo esc_attr($user->ID) ?>" data-email="<?php echo esc_attr($user->user_email) ?>" <?php selected( $user->ID, $staff->getWpUserId() ) ?>><?php echo esc_html($user->display_name) ?></option>
                <?php endforeach ?>
            </select>
        </div>
    <?php endif ?>

    <div class="row">
        <div class="col-sm-6">
            <div class="form-group">
                <label for="bookme-pro-email"><?php esc_html_e( 'Email', 'bookme_pro' ) ?></label>
                <input class="form-control" id="bookme-pro-email" name="email"
                       value="<?php echo esc_attr( $staff->getEmail() ) ?>"
                       type="text"/>
            </div>
        </div>
        <div class="col-sm-6">
            <div class="form-group">
                <label for="bookme-pro-phone"><?php esc_html_e( 'Phone', 'bookme_pro' ) ?></label>
                <input class="form-control" id="bookme-pro-phone"
                       value="<?php echo esc_attr( $staff->getPhone() ) ?>"
                       type="text"/>
            </div>
        </div>
    </div>

    <div class="form-group">
        <label for="bookme-pro-info"><?php esc_html_e( 'Info', 'bookme_pro' ) ?></label>
        <p class="help-block">
            <?php printf( esc_html__( 'This text can be inserted into notifications with %s code.', 'bookme_pro' ), '{staff_info}' ) ?>
        </p>
        <textarea id="bookme-pro-info" name="info" rows="3" class="form-control"><?php echo esc_textarea( $staff->getInfo() ) ?></textarea>
    </div>

    <div class="form-group">
        <label for="bookme-pro-visibility"><?php esc_html_e( 'Visibility', 'bookme_pro' ) ?></label>
        <p class="help-block">
            <?php esc_html_e( 'To make staff member invisible to your customers set the visibility to "Private".', 'bookme_pro' ) ?>
        </p>
        <select name="visibility" class="form-control" id="bookme-pro-visibility">
            <option value="public" <?php selected( $staff->getVisibility(), 'public' ) ?>><?php esc_html_e( 'Public', 'bookme_pro' ) ?></option>
            <option value="private" <?php selected( $staff->getVisibility(), 'private' ) ?>><?php esc_html_e( 'Private', 'bookme_pro' ) ?></option>
        </select>
    </div>
    <?php BookmePro\Lib\Proxy\Shared::renderStaffForm( $staff ) ?>
<hr>
    <div class="form-group">
        <h3><?php esc_html_e( 'Google Calendar integration', 'bookme_pro' ) ?></h3>
        <p class="help-block">
            <?php esc_html_e( 'Synchronize staff member appointments with Google Calendar.', 'bookme_pro' ) ?>
        </p>
        <p>
            <?php if ( isset( $authUrl ) ) : ?>
                <?php if ( $authUrl ) : ?>
                    <a href="<?php echo esc_url($authUrl) ?>"><?php esc_html_e( 'Connect', 'bookme_pro' ) ?></a>
                <?php else : ?>
                    <?php printf( __( 'Please configure Google Calendar <a href="%s">settings</a> first', 'bookme_pro' ), \BookmePro\Lib\Utils\Common::escAdminUrl( \BookmePro\Backend\Controllers\Settings\Controller::page_slug, array( 'tab' => 'google_calendar' ) ) ) ?>
                <?php endif ?>
            <?php else : ?>
                <?php esc_html_e( 'Connected', 'bookme_pro' ) ?> (<a href="<?php echo \BookmePro\Lib\Utils\Common::escAdminUrl( \BookmePro\Backend\Controllers\Staff\Controller::page_slug, array( 'google_logout' => $staff->getId() ) ) ?>"><?php esc_html_e( 'disconnect', 'bookme_pro' ) ?></a>)
            <?php endif ?>
        </p>
    </div>
    <?php if ( ! isset( $authUrl ) ) : ?>
        <div class="form-group">
            <label for="bookme-pro-calendar-id"><?php esc_html_e( 'Calendar', 'bookme_pro' ) ?></label>
            <select class="form-control" name="google_calendar_id" id="bookme-pro-calendar-id">
                <?php foreach ( $google_calendars as $id => $calendar ) : ?>
                    <option
                        <?php selected( $staff->getGoogleCalendarId() == $id || $staff->getGoogleCalendarId() == '' && $calendar['primary'] ) ?>
                            value="<?php echo esc_attr( $id ) ?>">
                        <?php echo esc_html( $calendar['summary'] ) ?>
                    </option>
                <?php endforeach ?>
            </select>
        </div>
    <?php endif ?>

    <input type="hidden" name="id" value="<?php echo esc_attr($staff->getId()) ?>">
    <input type="hidden" name="attachment_id" value="<?php echo esc_attr($staff->getAttachmentId()) ?>">
    <?php \BookmePro\Lib\Utils\Common::csrf() ?>

    <div class="panel-footer">
        <?php \BookmePro\Lib\Utils\Common::customButton( '', 'btn-default btn-lg slidePanel-close', esc_html__( 'Cancel', 'bookme_pro' ) ) ?>
        <?php \BookmePro\Lib\Utils\Common::customButton( 'bookme-pro-details-save', 'btn-lg btn-primary', esc_html__( 'Save', 'bookme_pro' ) ) ?>
    </div>
</form>